CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_growth.c File Reference

CCL

Macros | Functions
ccl_test_growth.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include <stdio.h>`
`#include <math.h>`

## Macros
#define | GROWTH_TOLERANCE 1.0e-4

## Functions
| CTEST_DATA (growth)
| CTEST_SETUP (growth)
| CTEST2 (growth, model_1)
| CTEST2 (growth, model_2)
| CTEST2 (growth, model_3)
| CTEST2 (growth, model_4)
| CTEST2 (growth, model_5)
| CTEST2 (growth, mgrowth)

## Macro Definition Documentation

## ◆ GROWTH_TOLERANCE

#define GROWTH_TOLERANCE 1.0e-4

## Function Documentation

## ◆ CTEST2() [1/6]

CTEST2 | ( | growth | ,
|  | model_1 |
| ) |  |

## ◆ CTEST2() [2/6]

CTEST2 | ( | growth | ,
|  | model_2 |
| ) |  |

## ◆ CTEST2() [3/6]

CTEST2 | ( | growth | ,
|  | model_3 |
| ) |  |

## ◆ CTEST2() [4/6]

CTEST2 | ( | growth | ,
|  | model_4 |
| ) |  |

## ◆ CTEST2() [5/6]

CTEST2 | ( | growth | ,
|  | model_5 |
| ) |  |

## ◆ CTEST2() [6/6]

CTEST2 | ( | growth | ,
|  | mgrowth |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | growth |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | growth |  | ) |